@@ -1,5 +1,207 @@
 #if 0
 
+N_("Struwen")
+N_("Struven are yeast pancakes which are traditionally eaten on good Friday in Germany, predominantly in Münsterland, but also in lower Rhine region.")
+N_("https://de.wikipedia.org/wiki/Struwen")
+N_("[image:1]Heat up 375ml milk in the microwave or on the stove until it is lukewarm. Don't boil!")
+N_("[image:2]Mix flour, yeast, sugar, eggs, warm milk and salt with a mixer.")
+N_("[image:5]Fold in the raisins with a spoon.")
+N_("[timer:00:30:00]Cover and let rise.")
+N_("[image:8]Use two table spoons to lift small balls of the soft dough into boiling oil and brown the small pancakes from both sides on medium heat.")
+N_("[image:0]Serve with cinnamon, sugar and applesauce.")
+N_("Struven can easily burn, therefore use only medium heat when browning.")
+N_("Use several pans to speed things up.")
+N_("Sous Vide")
+N_("An extremely simple French recipe.")
+N_("It goes well with any soft side dish like plain rice, cooked potatoes or tomato&lettuce salad.")
+N_("1. Pat the steaks with black pepper, olive oil and rosemary, and let it rest absorbing flavours.")
+N_("2. Heat a skillet with a mix of pork fat and oil, after a moment add the steaks. Sear until a crust forms, then flip and re-sear. For thick steaks, sear the sides as well. Don’t overcrowd the skillet, and work in batches if needed. Set the steaks aside.")
+N_("3. Reduce the skillet heat to low-medium, then add the wine and the spices used to marinate the meat. Reduce by half, stirring occasionally. While the sauce simmers, slice the steaks and scatter with some extra salt and black pepper. ")
+N_("4. Once the sauce is reduced, remove from heat and stir. Plate the steaks, then pour the reduced sauce over them and serve with plain rice or potatoes.")
+N_("Pork fat is optional.")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Chicken gravy")
+N_("This is a recipe I found in a book about Swabian cuisine. I just translated it.")
+N_("Mix everything. Cook it. Use it or store it.")
+N_("It works well to use it in the spot or to store it for later.")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Midsummer Night's Dream")
+N_("I made up this dessert in a very hot evening of summer.")
+N_("Fill a cup with ice cream adding Muesli, Chocolate and Nuts on top.")
+N_("Optionally, if you like it very sweet, you can add a bit of honey or caramel.")
+N_("If you use chocolate ice cream instead of vanilla, skip the chocolate on top.")
+N_("I made it with Vanilla, but you can try with other plain flavours like sabayon, chocolate or strawberry. ")
+N_("Nuts can be anything, walnuts, pecans, hazelnuts...  Cashews aren't that nice in sweet dishes but if you like them, go ahead.")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Boeuf Bourguignon")
+N_("A slightly modified version of a classic. Perfect to serve with potatoes in midwinter. ")
+N_("1. Warm a stockpot or dutch oven over medium heat; add the bacon and saute until crispy and its fat has rendered, about 10 minutes, stirring occasionally. Remove the bacon with a slotted spoon and set aside; increase heat to medium-high. Toss the beef in 2 tbsp of the flour plus the salt and pepper until well-coated; retain any excess flour. Add the beef pieces to the stockpot and brown until darkened and crispy, about 4 minutes per side, in batches if needed to prevent overcrowding.")
+N_("2. Set the beef aside once browned, then reduce heat to medium; add the onion to the stockpot and saute until softened, about 6 minutes. Add some butter, 1 tbsp at a time, if you run out of fat in the pot. Add the garlic and tomato paste, then sauté until aromatic, about 30 seconds. Add the remaining 2 tbsp of flour plus any retained flour from dusting the beef; stir and toast until it emits a nutty smell, about 2 minutes.")
+N_("3. Add the wine, thyme, rosemary, and bay leaves; stir to combine. Bring to a simmer and allow to thicken, then add the beef and any accumulated juices plus the beef bones. Add enough beef broth to nearly cover the beef. Cover, reduce heat to low, and simmer until nearly tender, about 2 hours.")
+N_("4. Uncover and increase heat to medium-low. Fish out the bones with tongs and discard or rinse and use to make a batch of beef broth. Add the carrots and simmer, uncovered, for 10 minutes, then add the pearl onions and simmer for 5 minutes. Finally, add the mushrooms and simmer until the meat and vegetables are softened, about 10 more minutes.")
+N_("5. At this point the sauce should be very thick; if so, stir in the bacon, add salt and pepper to taste, then serve garnished with chopped parsley. If the sauce is thin, remove the meat and vegetables with a slotted spoon and set aside, then reduce the sauce over medium-high heat until very thick. When ready to serve, return the meat, vegetables, and bacon to the pot to warm, and salt and pepper to taste, then serve garnished with chopped parsley.")
+N_("** Serve with mashed or baked potatoes.")
+N_("**Beef can be short ribs or boneless, as you like it.")
+N_("**If not Broth, plain Water is fine.")
+N_("**Onions can be the tiny ones, \"pearl onions\", or just normal ones. As long as they aren't too strong, is okay.")
+N_("**If no Champignons are available, choose a soft flavoured mushroom of some kind. In any case, they must be fresh not canned.")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Grilled salad")
+N_("A strengthen salad.")
+N_("1. Preheat your oven to 200°C. Toss the tomatoes with some olive oil, salt, and pepper on a baking surface. Roast them a bit, very carefully.")
+N_("2. To make the short version Caesar dressing, chop the garlic and anchovy into a paste, then add to a mixing bowl. Whisk in the remaining ingredients, add salt and pepper to taste, and add a bit more lemon juice if the dressing gets too thick.")
+N_("3. Prepare the chicken for grilling. Place the chicken flat on a cutting board, then slice each breast in half lengthwise to make 2 thin butterflied cutlets, 8 total. Grill them with some olive oil, salt and pepper; then set aside.")
+N_("4. Slice the lettuce in big halves, then brush with more olive oil and sprinkle with a bit of salt. Grill cut-side-down until for 1 minute or so.")
+N_("5. Slice the chicken into bite-sized pieces, then put everything together: place the lettuce cut-side-up, then scatter with chicken and roasted tomatoes; drizzle with the dressing and scatter with some shredded parmesan cheese.")
+N_("** The tomatoes, dressing, and chicken can all be made up to a day in advance.")
+N_("Romaine Salad")
+N_("Romaine Salad")
+N_("Romaine Salad")
+N_("Romaine Salad")
+N_("Romaine Salad")
+N_("Romaine Salad")
+N_("Caesar dressing")
+N_("Caesar dressing")
+N_("Caesar dressing")
+N_("Caesar dressing")
+N_("Caesar dressing")
+N_("Any meat marinade")
+N_("This is a very simple marinade that suits any kind of meat.")
+N_("The best result is making a lot and storing it in pots in a cool place.")
+N_("Mix everything and store it in jars or pots to further use.")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Farikal")
+N_("Fårikål is a Norwegian lamb and cabbage stew, very simple but really good for cold winters. This is my personal version (with Basil).")
+N_("1. Layer the bottom of a stockpot or dutch oven with lamb pieces, then sprinkle with a little of the salt. Add a layer of cabbage, then another layer of lamb and salt, and so on. Add the peppercorns and broth, then enough water to just cover everything. Bring to a simmer over high heat, then reduce heat to low and gently simmer until the lamb pulls away easily from the bone, about 2 hours. Add the potatoes during the last 30 minutes of simmering.")
+N_("2. Preheat your oven on the broil setting. Carefully remove the lamb pieces from the oven and place on a baking sheet. Broil the lamb until darkened and crispy, about 2 minutes per side. Return the lamb to the pot, season the stew with salt to taste, and serve.")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Colita con Chimichurri")
+N_("This recipe is original from Argentine and contains one of the many version of a popular sauce: Chimichurri.")
+N_("It's not restricted to Christmas and actually can be eaten warm or cold, and taste awesome in any way.")
+N_("1. Combine the marinade ingredients in a small bowl; stir to combine. Rub the marinade all over the tri-tip and set aside. Warm up the grill for indirect moderate heat: if using a charcoal grill, bank the coals to one side; if using a gas grill, ignite the burners on one side.")
+N_("2. Place the tri-tip on the cool side of the grill and cook until it reaches an internal temperature of 110F, about 25 minutes. As the meat cooks, combine the Chimichurri ingredients and set aside.")
+N_("3. Move the tri-tip to the hot side of the grill and cook on each side until lightly charred, about 2 minutes per side. Remove from the grill and rest for 10 minutes before slicing against the grain; serve with roasted or baked potatoes and the Chimichurri and lemon wedges for flavouring.")
+N_("** Meat used:  Loin, Sirloin, Trip-Tip or anything like that.")
+N_("** Onions are always less than garlic.")
+N_("** Chili peppers can be fresh and cut very tiny, just the seeds or dry  (seeds or flakes).")
+N_("Meat")
+N_("Chimichurri")
+N_("Chimichurri")
+N_("Chimichurri")
+N_("Chimichurri")
+N_("Chimichurri")
+N_("Chimichurri")
+N_("Chimichurri")
+N_("Chimichurri")
+N_("Stamina v1")
+N_("This is considered a health drink.")
+N_(" Good for stamina")
+N_("This is the tinted for blending.")
+N_("Depending on the blender but for me this is what I do.")
+N_("1 Cut up your beetroot in to four piedes. ")
+N_("2 Cut your Kale into four pieces. ")
+N_("3 Make sure the dry skin is off the garlic clove Before putting in blender.")
+N_("4 Add the coconut water. ")
+N_("5 blend away to your perfection")
+N_("I hope you enjoy!!!")
+N_("Original V-8 Recipe")
+N_("Yield roughly 32 oz. Trust me best served cold. If you add Tabasco, black pepper, and Worcestershire sauce you got yourself a spicy V-8.")
+N_("This recipe is intended for juicing.")
+N_("Peach Pine Delight")
+N_("Peaches, pineapple, and pomegranate juice blended to perfection. I hope you enjoy!")
+N_("Place items in blender and blend it.")
+N_("Endurance 1.0")
+N_("This is intended for blending. However if you want to juice this I recommend. ")
+N_("1 package cherries")
+N_("1 bushel Kale")
+N_("4 large bananas")
+N_("½ medium sweet potatoes")
+N_("This is intended for blending")
+N_("Okonomiyaki (Osaka style)")
+N_("Okonomiyaki: 'Okonomi' meaning \"your choice\", and 'yaki' meaning \"fried\".  This dish, as I have experienced it, is a cabbage pancake.")
+N_("This recipe is vegetarian, but it is also apparently very good if you fry okonomiyaki on top of a weave of bacon. When you have finished cooking, you can also top your okonomiyaki with katsuoboshi (bonito flakes) for a fun fishy topping.")
+N_("In a large bowl, combine flour, eggs, and water. Whisk until batter is smooth. Mix in chili flakes, cracked pepper, and sea salt, then set aside.")
+N_("Finely chop 1/4 of a head of cabbage (approx. 400 ml) and add it to the batter. Grating also works too if you prefer a more uniform texture.")
+N_("Finely chop green onions. Set aside the dark green parts of the onion, which will be used as a garnish later. Add the chopped green onions to the batter.")
+N_("Finely chop half an onion and add it to the batter. Feel free to add anything else you like at this point (shredded carrots are a nice addition).")
+N_("Fold the batter over itself using a spatula, ensuring that the chopped cabbage is evenly coated.")
+N_("In a small non-stick frying pan, toast black sesame seeds on low heat for 2-5 minutes.")
+N_("Add coconut oil to the pan, turn the heat up to medium. Add the batter and cabbage mixture to the pan, using a spatula to clean up the sides of the pancake.")
+N_("[image:3]Cook for approximately 5 to 10 minutes on each side, then transfer to a cutting board.")
+N_("To make okonomiyaki sauce: combine ketchup, Worcestershire sauce, tamari soy sauce, and honey in a small bowl. Add some chili flakes or other spices to your preference.")
+N_("[image:2] Smother the okonomiyaki pancake with the sauce. Pipe Japanese mayonnaise on the pancake in a back-and-forth (chevron) pattern. Use a chopstick or butter knife to draw parallel lines through the sauces for a nice visual effect. Note, in the attached image, the sauces are reversed to better demonstrate the pattern.")
+N_("[image:0] Top the okonomiyaki with the reserved green onions.")
+N_("For the gluten-intolerant:")
+N_("- Soy sauce is typically fermented with wheat; ensure you are using proper \"tamari\" soy sauce, which is fermented with soy.")
+N_("-  Rice flour makes for a fine substitute to wheat flour")
+N_("Other notes:")
+N_("- Simple Okonomiyaki sauce is very similar to barbecue sauce, as such barbecue sauce is a fine substitute for the sauce recipe included here.")
+N_("- Mix in other goodies such as shredded carrots, etc as you please!")
+N_("- In the third image, the sauces are reversed (mayonaisse then okonomi sauce) to better show the pattern. Either sauce works as the base, but the order in the instructions in my preference")
+N_("Simple okonomi sauce")
+N_("Simple okonomi sauce")
+N_("Simple okonomi sauce")
+N_("Simple okonomi sauce")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Rouladen")
+N_("This is the German version of a popular Greek dish.")
+N_("In Spanish is called  \"Niños envueltos\"  and in Greek is \"Dolmades\".")
+N_("In the original recipe (Greek/Turkish) the meat rolls are wrapped with vine or cabbage leafs. Some versions use the leafs only without the meat.")
+N_("Cut the meat in thin slices and paint each one with mustard. ")
+N_("Chop two onions and parsley very little, and the other onion in big chunks. ")
+N_("Peel and chop the potatoes. Cook them until they're exceedingly tender.  Take them out of the pot and smash them. ")
+N_("Fry everything (vegs+wine+tomato+saucenbinden) except beef, pancetta and cucumbers. This will be the filling together with the cucumbers. ")
+N_("When the filling is warm, place a pancetta slice in the centre, some filling on it, cucumbers and then roll the meat. ")
+N_("Tie it with cord  (heat resistant, please!). ")
+N_("Place in the oven and cook them until they're done. ")
+N_("Serve the rouladen with baked potatoes or plain rice.")
+N_("Where it says  \"package of cucumbers\"  should be read as a bottle or pot.")
 N_("Burjji")
 N_("Burjji is one of those treats that you can have at any time.  It is usually served at roadside restaurants or stalls along highways but can also be seen in the cities as well.")
 N_("This is basically indian style scrambled eggs with veggies and chillis.  There are a lot of variations.")
