@@ -18,20 +18,22 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "config.h"
-
-#include <string.h>
-
-#include "gr-ingredients-viewer.h"
-#include "gr-ingredients-viewer-row.h"
-#include "gr-ingredients-list.h"
-#include "gr-ingredient.h"
-#include "gr-utils.h"
-
-#ifdef ENABLE_GSPELL
-#include <gspell/gspell.h>
-#endif
-
+ #include "config.h"
+ 
+ #include <string.h>
+ 
+ #include "gr-ingredients-viewer.h"
+ #include "gr-ingredients-viewer-row.h"
+ #include "gr-ingredients-list.h"
+ #include "gr-ingredient.h"
+ #include "gr-utils.h"
+ #include "gr-number.h"
+ #include "gr-convert-units.h"
+ #include "gr-unit.h"
+ 
+ #ifdef ENABLE_GSPELL
+ #include <gspell/gspell.h>
+ #endif
 
 struct _GrIngredientsViewer
 {
@@ -54,8 +56,7 @@ struct _GrIngredientsViewer
         GtkWidget *row_before;
         GtkWidget *row_after;
 
-        int scale_num;
-        int scale_denom;
+        double scale;
 };
 
 
@@ -69,7 +70,8 @@ enum {
         PROP_ACTIVE,
         PROP_INGREDIENTS,
         PROP_SCALE_NUM,
-        PROP_SCALE_DENOM
+        PROP_SCALE_DENOM,
+        PROP_SCALE
 };
 
 enum {
@@ -224,12 +226,8 @@ gr_ingredients_viewer_get_property (GObject    *object,
                 g_value_set_boolean (value, self->active_row != NULL);
                 break;
 
-          case PROP_SCALE_NUM:
-                g_value_set_int (value, self->scale_num);
-                break;
-
-          case PROP_SCALE_DENOM:
-                g_value_set_int (value, self->scale_denom);
+          case PROP_SCALE:
+                g_value_set_double (value, self->scale);
                 break;
 
           default:
@@ -320,24 +318,25 @@ gr_ingredients_viewer_set_ingredients (GrIngredientsViewer *viewer,
         ingredients = gr_ingredients_list_new (text);
         ings = gr_ingredients_list_get_ingredients (ingredients, viewer->title);
         for (i = 0; ings && ings[i]; i++) {
-                g_autofree char *s = NULL;
-                g_auto(GStrv) strv = NULL;
-                const char *amount;
-                const char *unit;
+                double amount;
+                GrUnit unit;
                 GtkWidget *row;
+                g_autoptr(GString) s = NULL;
+                s = g_string_new ("");
+                double scale = viewer->scale;
 
-                s = gr_ingredients_list_scale_unit (ingredients, viewer->title, ings[i], viewer->scale_num, viewer->scale_denom);
-                strv = g_strsplit (s, " ", 2);
-                amount = strv[0];
-                unit = strv[1] ? strv[1] : "";
+                unit = gr_ingredients_list_get_unit (ingredients, viewer->title, ings[i]);
+                amount = gr_ingredients_list_get_amount (ingredients, viewer->title, ings[i]) * scale;
+
+                gr_convert_format (s, amount, unit);
 
                 row = g_object_new (GR_TYPE_INGREDIENTS_VIEWER_ROW,
-                                    "amount", amount,
-                                    "unit", unit,
+                                    "unit", s->str,
                                     "ingredient", ings[i],
                                     "size-group", viewer->group,
                                     "editable", viewer->editable,
                                     NULL);
+
                 g_signal_connect (row, "delete", G_CALLBACK (delete_row), viewer);
                 g_signal_connect (row, "move", G_CALLBACK (move_row), viewer);
                 g_signal_connect (row, "edit", G_CALLBACK (edit_ingredient_row), viewer);
@@ -616,12 +615,8 @@ gr_ingredients_viewer_set_property (GObject      *object,
                 gr_ingredients_viewer_set_active (self, g_value_get_boolean (value));
                 break;
 
-          case PROP_SCALE_NUM:
-                self->scale_num = g_value_get_int (value);
-                break;
-
-          case PROP_SCALE_DENOM:
-                self->scale_denom = g_value_get_int (value);
+          case PROP_SCALE:
+                self->scale = g_value_get_double (value);
                 break;
 
           case PROP_INGREDIENTS:
@@ -639,8 +634,7 @@ gr_ingredients_viewer_init (GrIngredientsViewer *self)
         gtk_widget_set_has_window (GTK_WIDGET (self), FALSE);
         gtk_widget_init_template (GTK_WIDGET (self));
 
-        self->scale_num = 1;
-        self->scale_denom = 1;
+        self->scale = 1.0;
         self->group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
 #if defined(ENABLE_GSPELL) && defined(GSPELL_TYPE_ENTRY)
@@ -699,6 +693,11 @@ gr_ingredients_viewer_class_init (GrIngredientsViewerClass *klass)
                                   G_PARAM_READWRITE);
         g_object_class_install_property (object_class, PROP_SCALE_DENOM, pspec);
 
+        pspec = g_param_spec_double ("scale", NULL, NULL,
+                                  0.0, G_MAXDOUBLE, 1.0,
+                                  G_PARAM_READWRITE);
+        g_object_class_install_property (object_class, PROP_SCALE, pspec);
+
         signals[DELETE] = g_signal_new ("delete",
                                         G_TYPE_FROM_CLASS (object_class),
                                         G_SIGNAL_RUN_FIRST,
